@@ -28,7 +28,7 @@ from email import charset
 charset.add_charset('utf-8', None)
 emlpolicy = email.policy.EmailPolicy(utf8=True, cte_type='8bit', max_line_length=None)
 
-__VERSION__ = '0.5.1'
+__VERSION__ = '0.5.2'
 ATTESTATION_FORMAT_VER = '0.1'
 
 logger = logging.getLogger('b4')
@@ -39,7 +39,7 @@ FILENAME_RE = re.compile(r'^(---|\+\+\+) (\S+)')
 PASS_SIMPLE = '[P]'
 FAIL_SIMPLE = '[F]'
 PASS_FANCY = '[\033[32m\u2713\033[0m]'
-FAIL_FANCY = '[\033[31m\u2717\034[0m]'
+FAIL_FANCY = '[\033[31m\u2717\033[0m]'
 
 # You can use bash-style globbing here
 WANTHDRS = [
@@ -521,15 +521,22 @@ class LoreSeries:
                         if attpolicy in ('softfail', 'hardfail'):
                             logger.info('  %s %s', attfail, lmsg.full_subject)
                             # Which part failed?
-                            failed = ['commit metadata', 'commit message', 'patch content']
+                            fi = fm = fp = True
                             for attdoc in ATTESTATIONS:
                                 for i, m, p in attdoc.hashes:
                                     if p == lmsg.attestation.p:
-                                        failed.remove('patch content')
+                                        fp = False
                                     if m == lmsg.attestation.m:
-                                        failed.remove('commit message')
+                                        fm = False
                                     if i == lmsg.attestation.i:
-                                        failed.remove('commit metadata')
+                                        fi = False
+                            failed = list()
+                            if fp:
+                                failed.append('patch content')
+                            if fm:
+                                failed.append('commit message')
+                            if fi:
+                                failed.append('patch metadata')
                             atterrors.append('Patch %s/%s failed attestation (%s)' % (at, lmsg.expected,
                                                                                       ', '.join(failed)))
                         else:
@@ -851,6 +858,7 @@ class LoreMessage:
                 # Whatever, we'll use utf-8 and hope for the best
                 payload = payload.decode('utf-8', errors='replace')
                 part.set_param('charset', 'utf-8')
+                self.charset = 'utf-8'
             if self.body is None:
                 self.body = payload
                 continue
@@ -1196,7 +1204,7 @@ class LoreMessage:
             signature = sparts[1]
             body = sparts[0].rstrip('\n')
 
-        parts = body.split('\n---\n', 1)
+        parts = re.split('^---\n', body, maxsplit=1, flags=re.M)
         if len(parts) == 2:
             basement = parts[1].rstrip('\n')
         elif body.find('\ndiff ') >= 0:
@@ -1233,6 +1241,8 @@ class LoreMessage:
             if githeaders == trailers:
                 # This is a message that consists of just trailers?
                 githeaders = list()
+            if nlines:
+                message = '\n'.join(nlines)
             return githeaders, message, trailers, basement, signature
 
         # Add all parts between first and last to mparts
@@ -1378,9 +1388,14 @@ class LoreSubject:
             self.reply = True
             subject = re.sub(r'^\w+:\s*\[', '[', subject)
 
+        # Fix [PATCHv3] to be properly [PATCH v3]
+        subject = re.sub(r'^\[\s*(patch)(v\d+).*', '[$1 $2$3', subject, flags=re.I)
+
         # Find all [foo] in the title
         while subject.find('[') == 0:
             matches = re.search(r'^\[([^\]]*)\]', subject)
+            if not matches:
+                break
             for chunk in matches.groups()[0].split():
                 # Remove any trailing commas or semicolons
                 chunk = chunk.strip(',;')
